@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -25,7 +25,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 from smartcard.Exceptions import SmartcardException
 
 
-class ATR:
+class ATR(object):
     """ATR class."""
 
     clockrateconversion = [372, 372, 558, 744, 1116, 1488, 1860, 'RFU',
@@ -105,14 +105,25 @@ class ATR:
             if self.hasTB[n]:
                 self.TB[n] = self.bytes[offset + self.hasTA[n] + self.hasTB[n]]
             if self.hasTC[n]:
-                self.TC[n] = self.bytes[offset + self.hasTA[n] + self.hasTB[n] + self.hasTC[n]]
+                self.TC[n] = self.bytes[offset +\
+                             self.hasTA[n] +\
+                             self.hasTB[n] +\
+                             self.hasTC[n]]
             if self.hasTD[n]:
-                self.TD[n] = self.bytes[offset + self.hasTA[n] + self.hasTB[n] + self.hasTC[n] + self.hasTD[n]]
+                self.TD[n] = self.bytes[offset +\
+                             self.hasTA[n] +\
+                             self.hasTB[n] +\
+                             self.hasTC[n] +\
+                             self.hasTD[n]]
 
-            self.interfaceBytesCount += self.hasTA[n] + self.hasTB[n] + self.hasTC[n] + self.hasTD[n]
+            self.interfaceBytesCount += self.hasTA[n] +\
+                                        self.hasTB[n] +\
+                                        self.hasTC[n] +\
+                                        self.hasTD[n]
             TD = self.TD[n]
             hasTD = self.hasTD[n]
-            offset = offset + self.hasTA[n] + self.hasTB[n] + self.hasTC[n] + self.hasTD[n]
+            offset = offset + self.hasTA[n] + self.hasTB[n] +\
+                              self.hasTC[n] + self.hasTD[n]
             n = n + 1
 
         # historical bytes
@@ -235,17 +246,17 @@ class ATR:
     def isT0Supported(self):
         """Return True if T=0 is supported."""
         protocols = self.getSupportedProtocols()
-        return protocols.has_key('T=0')
+        return 'T=0' in protocols
 
     def isT1Supported(self):
         """Return True if T=1 is supported."""
         protocols = self.getSupportedProtocols()
-        return protocols.has_key('T=1')
+        return 'T=1' in protocols
 
     def isT15Supported(self):
         """Return True if T=15 is supported."""
         protocols = self.getSupportedProtocols()
-        return protocols.has_key('T=15')
+        return 'T=15' in protocols
 
     def dump(self):
         """Dump the details of an ATR."""
@@ -279,7 +290,8 @@ class ATR:
 
     def __str__(self):
         """Returns a string representation of the ATR as a strem of bytes."""
-        return reduce(lambda a, b: a + "%-0.2X " % ((b + 256) % 256), self.bytes, '')
+        return reduce(lambda a, b: a + \
+                      "%-0.2X " % ((b + 256) % 256), self.bytes, '')
 
 
 if __name__ == '__main__':
@@ -299,4 +311,5 @@ if __name__ == '__main__':
         print 80 * '-'
         print a
         a.dump()
-        print reduce(lambda a, b: a + "%-0.2X " % ((b + 256) % 256), a.getHistoricalBytes(), '')
+        print reduce(lambda a, b: a + \
+                     "%-0.2X " % ((b + 256) % 256), a.getHistoricalBytes(), '')
