@@ -2,7 +2,7 @@
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -27,7 +27,7 @@ from smartcard.System import readers
 from smartcard.util import toHexString
 
 
-class Card:
+class Card(object):
     """Card class."""
 
     def __init__(self, reader, atr):
@@ -46,7 +46,8 @@ class Card:
         """Return True if self==other (same reader and same atr).
            Return False otherwise."""
         if isinstance(other, Card):
-            return (self.atr == other.atr and `self.reader` == `other.reader`)
+            return (self.atr == other.atr and
+                                repr(self.reader) == repr(other.reader))
         else:
             return False
 
@@ -55,6 +56,10 @@ class Card:
         False otherwise."""
         return not self.__eq__(other)
 
+    def __hash__(self):
+        """Returns a hash value for this object (str(self) is unique)."""
+        return hash(str(self))
+
     def createConnection(self):
         """Return a CardConnection to the Card object."""
         readerobj = None
@@ -68,5 +73,6 @@ class Card:
         if readerobj:
             return readerobj.createConnection()
         else:
-            #raise CardConnectionException('not a valid reader: ' + str(self.reader))
+            #raise CardConnectionException(
+            # 'not a valid reader: ' + str(self.reader))
             return None
