@@ -3,7 +3,7 @@ apdu transmission.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -48,7 +48,8 @@ class CardConnection(Observable):
         Observable.__init__(self)
         self.reader = reader
         self.errorcheckingchain = None
-        self.defaultprotocol = CardConnection.T0_protocol | CardConnection.T1_protocol
+        self.defaultprotocol = CardConnection.T0_protocol |\
+                                CardConnection.T1_protocol
 
     def __del__(self):
         """Connect to card."""
@@ -136,10 +137,16 @@ class CardConnection(Observable):
                     CardConnection.RAW_protocol
         """
         Observable.setChanged(self)
-        Observable.notifyObservers(self, CardConnectionEvent('command', [bytes, protocol]))
+        Observable.notifyObservers(self,
+                                   CardConnectionEvent(
+                                       'command',
+                                       [bytes, protocol]))
         data, sw1, sw2 = self.doTransmit(bytes, protocol)
         Observable.setChanged(self)
-        Observable.notifyObservers(self, CardConnectionEvent('response', [data, sw1, sw2]))
+        Observable.notifyObservers(self,
+                                   CardConnectionEvent(
+                                       'response',
+                                       [data, sw1, sw2]))
         if None != self.errorcheckingchain:
             self.errorcheckingchain[0](data, sw1, sw2)
         return data, sw1, sw2
@@ -161,10 +168,16 @@ class CardConnection(Observable):
         bytes:       list of bytes to transmit
         """
         Observable.setChanged(self)
-        Observable.notifyObservers(self, CardConnectionEvent('command', [controlCode, bytes]))
+        Observable.notifyObservers(self,
+                                   CardConnectionEvent(
+                                       'command',
+                                       [controlCode, bytes]))
         data = self.doControl(controlCode, bytes)
         Observable.setChanged(self)
-        Observable.notifyObservers(self, CardConnectionEvent('response', data))
+        Observable.notifyObservers(self,
+                                   CardConnectionEvent(
+                                       'response',
+                                       data))
         if None != self.errorcheckingchain:
             self.errorcheckingchain[0](data)
         return data
@@ -174,3 +187,24 @@ class CardConnection(Observable):
 
         Subclasses must override this method for implementing control."""
         pass
+
+    def getAttrib(self, attribId):
+        """return the requested attribute
+
+        attribId: attribute id like SCARD_ATTR_VENDOR_NAME
+        """
+        Observable.setChanged(self)
+        Observable.notifyObservers(self,
+                                   CardConnectionEvent(
+                                       'attrib',
+                                       [attribId]))
+        data = self.doGetAttrib(attribId)
+        if None != self.errorcheckingchain:
+            self.errorcheckingchain[0](data)
+        return data
+
+    def doGetAttrib(self, attribId):
+        """Performs the command get attrib.
+
+        Subclasses must override this method for implementing get attrib."""
+        pass
