@@ -5,7 +5,7 @@ upon CardConnection events.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -62,4 +62,6 @@ class ConsoleCardConnectionObserver(CardConnectionObserver):
             if [] == ccevent.args[0]:
                 print '<  [] ', "%-2X %-2X" % tuple(ccevent.args[-2:])
             else:
-                print '< ', toHexString(ccevent.args[0]), "%-2X %-2X" % tuple(ccevent.args[-2:])
+                print '< ', \
+                        toHexString(ccevent.args[0]), \
+                        "%-2X %-2X" % tuple(ccevent.args[-2:])
