@@ -8,7 +8,7 @@ upon reader insertion/removal.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -63,7 +63,7 @@ class CardObserver(Observer):
         pass
 
 
-class CardMonitor:
+class CardMonitor(object):
     """Class that monitors smart card insertion/removal.
     and notify observers
 
@@ -130,7 +130,7 @@ class CardMonitor:
         return getattr(self.instance, name)
 
 
-class CardMonitoringThread:
+class CardMonitoringThread(object):
     """Card insertion thread.
     This thread waits for card insertion.
     """
@@ -173,7 +173,8 @@ class CardMonitoringThread:
                     if addedcards != [] or removedcards != []:
                         self.cards = currentcards
                         self.observable.setChanged()
-                        self.observable.notifyObservers((addedcards, removedcards))
+                        self.observable.notifyObservers(
+                            (addedcards, removedcards))
 
                 # when CardMonitoringThread.__del__() is invoked in
                 # response to shutdown, e.g., when execution of the
@@ -204,7 +205,8 @@ class CardMonitoringThread:
 
     def __init__(self, observable):
         if not CardMonitoringThread.instance:
-            CardMonitoringThread.instance = CardMonitoringThread.__CardMonitoringThreadSingleton(observable)
+            CardMonitoringThread.instance = \
+               CardMonitoringThread.__CardMonitoringThreadSingleton(observable)
             CardMonitoringThread.instance.start()
 
     def __getattr__(self, name):
