@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -64,7 +64,7 @@ class __CardNames__(Synchronization):
 
     def dump(self):
         for k, v in self.db.iteritems():
-            print k, `loads(v)`
+            print k, repr(loads(v))
 
     def find(self, atr, reader=None):
         for k, v in self.db.iteritems():
@@ -74,7 +74,7 @@ class __CardNames__(Synchronization):
 synchronize(__CardNames__, "add delete dump find")
 
 
-class CardNames:
+class CardNames(object):
     """The CardNames organizes cards by a unique name and an associated
     smartcard.CardType.CardType."""
 
