@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -25,7 +25,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 from smartcard.pcsc.PCSCCardRequest import PCSCCardRequest
 
 
-class CardRequest:
+class CardRequest(object):
     """A CardRequest is used for waitForCard() invocations and specifies what
     kind of smart card an application is waited for.
     """
