@@ -10,7 +10,7 @@ the smartcard with a CardConnection.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -34,7 +34,7 @@ from smartcard.Exceptions import SmartcardException
 from smartcard.scard import *
 
 
-class CardService:
+class CardService(object):
     """Card service abstract class.
     Known subclasses: smartcard.PassThruCardService
     """
