@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -25,7 +25,7 @@ from smartcard.System import readers
 from smartcard.util import toHexString
 
 
-class CardType:
+class CardType(object):
     """Abstract base class for CardTypes.
 
     Known sub-classes: smartcard.CardType.AnyCardType
