@@ -4,7 +4,7 @@ Sample script that illustrates exclusive card connection decorators.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -29,8 +29,10 @@ from smartcard.CardConnectionObserver import ConsoleCardConnectionObserver
 from smartcard.CardConnection import CardConnection
 from smartcard.util import toHexString
 
-from smartcard.ExclusiveConnectCardConnection import ExclusiveConnectCardConnection
-from smartcard.ExclusiveTransmitCardConnection import ExclusiveTransmitCardConnection
+from smartcard.ExclusiveConnectCardConnection import \
+    ExclusiveConnectCardConnection
+from smartcard.ExclusiveTransmitCardConnection import \
+    ExclusiveTransmitCardConnection
 
 
 # define the apdus used in this script
@@ -48,7 +50,8 @@ observer = ConsoleCardConnectionObserver()
 cardservice.connection.addObserver(observer)
 
 # attach our decorator
-cardservice.connection = ExclusiveTransmitCardConnection(ExclusiveConnectCardConnection(cardservice.connection))
+cardservice.connection = ExclusiveTransmitCardConnection(
+    ExclusiveConnectCardConnection(cardservice.connection))
 
 # connect to the card and perform a few transmits
 cardservice.connection.connect()
