@@ -4,7 +4,7 @@ Sample script to illustrate toHexString() utility method
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -35,8 +35,10 @@ print 'toHexString(bytes, COMMA) =', toHexString(bytes, COMMA)
 print 'toHexString(bytes, PACK) =', toHexString(bytes, PACK)
 print 'toHexString(bytes, HEX) =', toHexString(bytes, HEX)
 print 'toHexString(bytes, HEX | COMMA) =', toHexString(bytes, HEX | COMMA)
-print 'toHexString(bytes, HEX | UPPERCASE) =', toHexString(bytes, HEX | UPPERCASE)
-print 'toHexString(bytes, HEX | UPPERCASE | COMMA) =', toHexString(bytes, HEX | UPPERCASE | COMMA)
+print 'toHexString(bytes, HEX | UPPERCASE) =', \
+    toHexString(bytes, HEX | UPPERCASE)
+print 'toHexString(bytes, HEX | UPPERCASE | COMMA) =', \
+    toHexString(bytes, HEX | UPPERCASE | COMMA)
 
 
 print 40 * '-'
@@ -47,8 +49,10 @@ print 'toHexString(bytes) =', toHexString(bytes)
 print 'toHexString(bytes, PACK) =', toHexString(bytes, PACK)
 print 'toHexString(bytes, HEX) =', toHexString(bytes, HEX)
 print 'toHexString(bytes, HEX | COMMA) =', toHexString(bytes, HEX | COMMA)
-print 'toHexString(bytes, HEX | UPPERCASE) =', toHexString(bytes, HEX | UPPERCASE)
-print 'toHexString(bytes, HEX | UPPERCASE | COMMA) =', toHexString(bytes, HEX | UPPERCASE | COMMA)
+print 'toHexString(bytes, HEX | UPPERCASE) =', \
+    toHexString(bytes, HEX | UPPERCASE)
+print 'toHexString(bytes, HEX | UPPERCASE | COMMA) =', \
+    toHexString(bytes, HEX | UPPERCASE | COMMA)
 
 
 import sys
