@@ -4,7 +4,7 @@ Sample for python PCSC wrapper module: get card ATR in first pcsc reader
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 Copyright 2010 Ludovic Rousseau
 Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
@@ -32,13 +32,17 @@ import smartcard.util
 try:
     hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
     if hresult != SCARD_S_SUCCESS:
-        raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
+        raise error(
+            'Failed to establish context: ' + \
+            SCardGetErrorMessage(hresult))
     print 'Context established!'
 
     try:
         hresult, readers = SCardListReaders(hcontext, [])
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to list readers: ' + \
+                SCardGetErrorMessage(hresult))
         if len(readers) < 1:
             raise Exception('No smart card readers')
         print 'PCSC Readers:', readers
@@ -47,7 +51,9 @@ try:
             print 'Trying to retreive ATR of card in', reader
 
             hresult, hcard, dwActiveProtocol = SCardConnect(
-                hcontext, reader, SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
+                hcontext,
+                reader,
+                SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
             if hresult != SCARD_S_SUCCESS:
                 print 'Unable to connect: ' + SCardGetErrorMessage(hresult)
             else:
@@ -57,23 +63,27 @@ try:
                 try:
                     hresult, reader, state, protocol, atr = SCardStatus(hcard)
                     if hresult != SCARD_S_SUCCESS:
-                        print 'failed to get status: ' + SCardGetErrorMessage(hresult)
+                        print 'failed to get status: ' + \
+                              SCardGetErrorMessage(hresult)
                     print 'Reader:', reader
-                    print 'State:', state
+                    print 'State:', hex(state)
                     print 'Protocol:', protocol
-                    print 'ATR:', smartcard.util.toHexString(atr, smartcard.util.HEX)
+                    print 'ATR:', smartcard.util.toHexString(
+                                        atr,
+                                        smartcard.util.HEX)
 
                 finally:
                     hresult = SCardDisconnect(hcard, SCARD_UNPOWER_CARD)
                     if hresult != SCARD_S_SUCCESS:
-                        print 'Failed to disconnect: ' + SCardGetErrorMessage(hresult)
+                        print 'Failed to disconnect: ' + \
+                            SCardGetErrorMessage(hresult)
                     print 'Disconnected'
 
-
     finally:
         hresult = SCardReleaseContext(hcontext)
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
+            raise error('Failed to release context: ' + \
+                            SCardGetErrorMessage(hresult))
         print 'Released context.'
 
 except Exception, e:
