@@ -4,7 +4,7 @@ Sample for python PCSC wrapper module: Detect card insertion/removal
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 Copyright 2010 Ludovic Rousseau
 Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
@@ -29,8 +29,10 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 from smartcard.scard import *
 import smartcard.util
 
-srTreeATR = [0x3B, 0x77, 0x94, 0x00, 0x00, 0x82, 0x30, 0x00, 0x13, 0x6C, 0x9F, 0x22]
-srTreeMask = [0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF]
+srTreeATR = \
+    [0x3B, 0x77, 0x94, 0x00, 0x00, 0x82, 0x30, 0x00, 0x13, 0x6C, 0x9F, 0x22]
+srTreeMask = \
+    [0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF]
 
 
 def printstate(state):
@@ -63,13 +65,17 @@ def printstate(state):
 try:
     hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
     if hresult != SCARD_S_SUCCESS:
-        raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
+        raise error(
+            'Failed to establish context: ' + \
+            SCardGetErrorMessage(hresult))
     print 'Context established!'
 
     try:
         hresult, readers = SCardListReaders(hcontext, [])
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to list readers: ' + \
+                SCardGetErrorMessage(hresult))
         print 'PCSC Readers:', readers
 
         readerstates = []
@@ -82,17 +88,21 @@ try:
             printstate(i)
 
         print '----- Please insert or remove a card ------------'
-        hresult, newstates = SCardGetStatusChange(hcontext, INFINITE, newstates)
+        hresult, newstates = SCardGetStatusChange(
+                                hcontext,
+                                INFINITE,
+                                newstates)
 
         print '----- New reader and card states are: -----------'
         for i in newstates:
             printstate(i)
 
-
     finally:
         hresult = SCardReleaseContext(hcontext)
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to release context: ' + \
+                SCardGetErrorMessage(hresult))
         print 'Released context.'
 
     import sys
