@@ -4,7 +4,7 @@ Sample for python PCSC wrapper module: List cards introduced in the system
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 Copyright 2010 Ludovic Rousseau
 Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
@@ -30,22 +30,29 @@ from smartcard.scard import *
 
 if 'winscard' == resourceManager:
     # Cryptoflex 8k v2 is introduced in standard Windows 2000
-    slbCryptoFlex8kv2ATR = [0x3B, 0x95, 0x15, 0x40, 0x00, 0x68, 0x01, 0x02, 0x00, 0x00]
+    slbCryptoFlex8kv2ATR = \
+        [0x3B, 0x95, 0x15, 0x40, 0x00, 0x68, 0x01, 0x02, 0x00, 0x00]
     try:
         hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to establish context: ' + \
+                SCardGetErrorMessage(hresult))
         print 'Context established!'
 
         try:
             hresult, card = SCardListCards(hcontext, slbCryptoFlex8kv2ATR, [])
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failure to locate Schlumberger Cryptoflex 8k v2 card: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failure to locate Schlumberger Cryptoflex 8k v2 card: ' +\
+                    SCardGetErrorMessage(hresult))
             print 'Located by ATR:', card
 
             hresult, cards = SCardListCards(hcontext, [], [])
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failure to list cards: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failure to list cards: ' + \
+                    SCardGetErrorMessage(hresult))
             print 'Cards:', cards
 
             for i in cards:
@@ -61,7 +68,9 @@ if 'winscard' == resourceManager:
         finally:
             hresult = SCardReleaseContext(hcontext)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to release context: ' + \
+                    SCardGetErrorMessage(hresult))
             print 'Released context.'
 
     except error, e:
