@@ -4,7 +4,7 @@ Sample for python PCSC wrapper module: illustrate reader groups functions
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 Copyright 2010 Ludovic Rousseau
 Author: Ludovic Rousseau, mailto:ludovic.rousseau@free.fr
@@ -33,83 +33,120 @@ newgroup = 'MyReaderGroup'
 try:
     hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
     if hresult != SCARD_S_SUCCESS:
-        raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
+        raise error(
+            'Failed to establish context: ' + \
+            SCardGetErrorMessage(hresult))
     print 'Context established!'
 
     try:
         hresult, readers = SCardListReaders(hcontext, [])
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to list readers: ' + \
+                SCardGetErrorMessage(hresult))
         print 'PCSC Readers in all groups:', readers
 
         hresult, readerGroups = SCardListReaderGroups(hcontext)
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Unable to list reader groups: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Unable to list reader groups: ' + \
+                SCardGetErrorMessage(hresult))
         print 'PCSC Reader groups:', readerGroups
 
         if 'winscard' == resourceManager:
 
             hresult = SCardIntroduceReaderGroup(hcontext, newgroup)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Unable to introduce reader group: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to introduce reader group: ' + \
+                    SCardGetErrorMessage(hresult))
 
             dummyreader = readers[0] + ' dummy'
             hresult = SCardIntroduceReader(hcontext, dummyreader, readers[0])
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Unable to introduce reader: ' + dummyreader + ' : ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to introduce reader: ' + \
+                    dummyreader + ' : ' + \
+                    SCardGetErrorMessage(hresult))
 
             hresult, readers = SCardListReaders(hcontext, [])
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to list readers: ' + \
+                    SCardGetErrorMessage(hresult))
             print 'PCSC Readers in all groups:', readers
 
             hresult = SCardAddReaderToGroup(hcontext, dummyreader, newgroup)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Unable to add reader to group: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to add reader to group: ' + \
+                    SCardGetErrorMessage(hresult))
 
             hresult, readerGroups = SCardListReaderGroups(hcontext)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Unable to list reader groups: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to list reader groups: ' + \
+                    SCardGetErrorMessage(hresult))
             print 'PCSC Reader groups:', readerGroups
 
             hresult, readers = SCardListReaders(hcontext, [newgroup])
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failed to list readers in group ' + newgroup + ' : ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to list readers in group ' + \
+                    newgroup + ' : ' + \
+                    SCardGetErrorMessage(hresult))
             print 'PCSC Readers in reader group', newgroup, ':', readers
 
-            hresult = SCardRemoveReaderFromGroup(hcontext, dummyreader, newgroup)
+            hresult = SCardRemoveReaderFromGroup(
+                hcontext,
+                dummyreader,
+                newgroup)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Unable to remove reader from group: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to remove reader from group: ' + \
+                    SCardGetErrorMessage(hresult))
 
             hresult, readerGroups = SCardListReaderGroups(hcontext)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Unable to list reader groups: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to list reader groups: ' + \
+                    SCardGetErrorMessage(hresult))
             print 'PCSC Reader groups:', readerGroups
 
             hresult = SCardForgetReaderGroup(hcontext, newgroup)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Unable to forget reader group: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to forget reader group: ' + \
+                    SCardGetErrorMessage(hresult))
 
             hresult = SCardForgetReader(hcontext, dummyreader)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failed to forget readers ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to forget readers ' + \
+                    SCardGetErrorMessage(hresult))
 
             hresult, readers = SCardListReaders(hcontext, [])
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failed to list readers: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to list readers: ' + \
+                    SCardGetErrorMessage(hresult))
             print 'PCSC Readers in all groups:', readers
 
         elif 'pcsclite' == resourceManager:
             hresult, readers = SCardListReaders(hcontext, readerGroups)
             if hresult != SCARD_S_SUCCESS:
-                raise error, 'Failed to list readers in groups ' + `readerGroups` + ' : ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to list readers in groups ' + \
+                    repr(readerGroups) + ' : ' + \
+                    SCardGetErrorMessage(hresult))
             print 'PCSC Readers in reader group', readerGroups, ':', readers
 
-
     finally:
         hresult = SCardReleaseContext(hcontext)
         if hresult != SCARD_S_SUCCESS:
-            raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to release context: ' + \
+                SCardGetErrorMessage(hresult))
         print 'Released context.'
 
     import sys
