@@ -4,7 +4,7 @@ Simple panel that defines a dialog to send APDUs to a card.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -26,7 +26,8 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 import wx
 
 from smartcard.wx.APDUHexValidator import APDUHexValidator
-from smartcard.wx.SimpleSCardAppEventObserver import SimpleSCardAppEventObserver
+from smartcard.wx.SimpleSCardAppEventObserver import \
+    SimpleSCardAppEventObserver
 from smartcard.util import toBytes, toHexString
 
 [
@@ -56,41 +57,47 @@ class SampleAPDUManagerPanel(wx.Panel, SimpleSCardAppEventObserver):
 
     # callbacks from SimpleSCardAppEventObserver interface
     def OnActivateCard(self, card):
-        """Called when a card is activated by double-clicking on the card or reader tree control or toolbar.
+        """Called when a card is activated by double-clicking
+        on the card or reader tree control or toolbar.
         In this sample, we just connect to the card on the first activation."""
         SimpleSCardAppEventObserver.OnActivateCard(self, card)
-        self.feedbacktext.SetLabel('Activated card: ' + `card`)
+        self.feedbacktext.SetLabel('Activated card: ' + repr(card))
         self.transmitbutton.Enable()
 
     def OnActivateReader(self, reader):
-        """Called when a reader is activated by double-clicking on the reader tree control or toolbar."""
+        """Called when a reader is activated by double-clicking
+        on the reader tree control or toolbar."""
         SimpleSCardAppEventObserver.OnActivateReader(self, reader)
-        self.feedbacktext.SetLabel('Activated reader: ' + `reader`)
+        self.feedbacktext.SetLabel('Activated reader: ' + repr(reader))
         self.transmitbutton.Disable()
 
     def OnDeactivateCard(self, card):
-        """Called when a card is deactivated in the reader tree control or toolbar."""
+        """Called when a card is deactivated in the reader
+        tree control or toolbar."""
         SimpleSCardAppEventObserver.OnActivateCard(self, card)
-        self.feedbacktext.SetLabel('Deactivated card: ' + `card`)
+        self.feedbacktext.SetLabel('Deactivated card: ' + repr(card))
         self.transmitbutton.Disable()
 
     def OnDeselectCard(self, card):
-        """Called when a card is selected by clicking on the card or reader tree control or toolbar."""
+        """Called when a card is selected by clicking on the
+        card or reader tree control or toolbar."""
         SimpleSCardAppEventObserver.OnSelectCard(self, card)
-        self.feedbacktext.SetLabel('Deselected card: ' + `card`)
+        self.feedbacktext.SetLabel('Deselected card: ' + repr(card))
         self.transmitbutton.Disable()
 
     def OnSelectCard(self, card):
-        """Called when a card is selected by clicking on the card or reader tree control or toolbar."""
+        """Called when a card is selected by clicking on the
+        card or reader tree control or toolbar."""
         SimpleSCardAppEventObserver.OnSelectCard(self, card)
-        self.feedbacktext.SetLabel('Selected card: ' + `card`)
+        self.feedbacktext.SetLabel('Selected card: ' + repr(card))
         if hasattr(self.selectedcard, 'connection'):
             self.transmitbutton.Enable()
 
     def OnSelectReader(self, reader):
-        """Called when a reader is selected by clicking on the reader tree control or toolbar."""
+        """Called when a reader is selected by clicking on the
+        reader tree control or toolbar."""
         SimpleSCardAppEventObserver.OnSelectReader(self, reader)
-        self.feedbacktext.SetLabel('Selected reader: ' + `reader`)
+        self.feedbacktext.SetLabel('Selected reader: ' + repr(reader))
         self.transmitbutton.Disable()
 
     # callbacks
@@ -99,7 +106,8 @@ class SampleAPDUManagerPanel(wx.Panel, SimpleSCardAppEventObserver):
             apdu = self.commandtextctrl.GetValue()
             if type(u'') == type(apdu):
                 apdu = apdu.encode('utf8')
-            data, sw1, sw2 = self.selectedcard.connection.transmit(toBytes(apdu))
+            data, sw1, sw2 = \
+                self.selectedcard.connection.transmit(toBytes(apdu))
             self.SW1textctrl.SetValue("%x" % sw1)
             self.SW2textctrl.SetValue("%x" % sw2)
             self.responsetextctrl.SetValue(toHexString(data + [sw1, sw2]))
@@ -108,18 +116,76 @@ class SampleAPDUManagerPanel(wx.Panel, SimpleSCardAppEventObserver):
     def layoutControls(self):
 
         # create controls
-        statictextCommand = wx.StaticText(self, ID_TEXT_COMMAND, "Command", wx.DefaultPosition, wx.DefaultSize, 0)
-        self.commandtextctrl = wx.TextCtrl(self, ID_TEXTCTRL_COMMAND, "",
-                                            wx.DefaultPosition, wx.DefaultSize, wx.TE_MULTILINE,
-                                            validator=APDUHexValidator())
-        statictextResponse = wx.StaticText(self, ID_TEXT_RESPONSE, "Response", wx.DefaultPosition, wx.DefaultSize, 0)
-        self.responsetextctrl = wx.TextCtrl(self, ID_TEXTCTRL_RESPONSE, "", wx.DefaultPosition, wx.DefaultSize, wx.TE_MULTILINE | wx.TE_READONLY)
-        statictextStatusWords = wx.StaticText(self, ID_TEXT_SW, "Status Words", wx.DefaultPosition, wx.DefaultSize, 0)
-        statictextSW1 = wx.StaticText(self, ID_TEXT_SW1, "SW1", wx.DefaultPosition, wx.DefaultSize, 0)
-        self.SW1textctrl = wx.TextCtrl(self, ID_TEXTCTRL_SW1, "", wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY)
-        statictextSW2 = wx.StaticText(self, ID_TEXT_SW2, "SW2", wx.DefaultPosition, wx.DefaultSize, 0)
-        self.SW2textctrl = wx.TextCtrl(self, ID_TEXTCTRL_SW2, "", wx.DefaultPosition, wx.DefaultSize, wx.TE_READONLY)
-        self.feedbacktext = wx.StaticText(self, ID_CARDSTATE, "", wx.DefaultPosition, wx.DefaultSize, 0)
+        statictextCommand = wx.StaticText(
+            self,
+            ID_TEXT_COMMAND,
+            "Command",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            0)
+        self.commandtextctrl = wx.TextCtrl(
+            self,
+            ID_TEXTCTRL_COMMAND, "",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            wx.TE_MULTILINE,
+            validator=APDUHexValidator())
+        statictextResponse = wx.StaticText(
+            self,
+            ID_TEXT_RESPONSE,
+            "Response",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            0)
+        self.responsetextctrl = wx.TextCtrl(
+            self,
+            ID_TEXTCTRL_RESPONSE,
+            "",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            wx.TE_MULTILINE | wx.TE_READONLY)
+        statictextStatusWords = wx.StaticText(
+            self,
+            ID_TEXT_SW,
+            "Status Words",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            0)
+        statictextSW1 = wx.StaticText(
+            self,
+            ID_TEXT_SW1,
+            "SW1",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            0)
+        self.SW1textctrl = wx.TextCtrl(
+            self,
+            ID_TEXTCTRL_SW1,
+            "",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            wx.TE_READONLY)
+        statictextSW2 = wx.StaticText(
+            self,
+            ID_TEXT_SW2,
+            "SW2",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            0)
+        self.SW2textctrl = wx.TextCtrl(
+            self,
+            ID_TEXTCTRL_SW2,
+            "",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            wx.TE_READONLY)
+        self.feedbacktext = wx.StaticText(
+            self,
+            ID_CARDSTATE,
+            "",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            0)
 
         # layout controls
         boxsizerCommand = wx.BoxSizer(wx.HORIZONTAL)
@@ -127,7 +193,8 @@ class SampleAPDUManagerPanel(wx.Panel, SimpleSCardAppEventObserver):
         boxsizerCommand.Add(self.commandtextctrl, 5, wx.EXPAND | wx.ALL, 5)
 
         boxsizerResponse = wx.BoxSizer(wx.HORIZONTAL)
-        boxsizerResponse.Add(statictextResponse, 1, wx.ALIGN_CENTER | wx.ALL, 5)
+        boxsizerResponse.Add(
+            statictextResponse, 1, wx.ALIGN_CENTER | wx.ALL, 5)
         boxsizerResponse.Add(self.responsetextctrl, 5, wx.EXPAND | wx.ALL, 5)
 
         boxsizerSW = wx.BoxSizer(wx.HORIZONTAL)
@@ -153,12 +220,18 @@ class SampleAPDUManagerPanel(wx.Panel, SimpleSCardAppEventObserver):
         boxsizerEvents = wx.StaticBoxSizer(staticboxEvents, wx.HORIZONTAL)
         boxsizerEvents.Add(self.feedbacktext, 0, wx.ALIGN_CENTER | wx.ALL, 5)
 
-
         sizerboxTransmitButton = wx.BoxSizer(wx.HORIZONTAL)
         sizerboxTransmitButton.Add([20, 20], 0, wx.ALIGN_CENTER | wx.ALL, 5)
-        self.transmitbutton = wx.Button(self, ID_TRANSMIT, "Transmit", wx.DefaultPosition, wx.DefaultSize, 0)
+        self.transmitbutton = wx.Button(
+            self,
+            ID_TRANSMIT,
+            "Transmit",
+            wx.DefaultPosition,
+            wx.DefaultSize,
+            0)
         self.transmitbutton.Disable()
-        sizerboxTransmitButton.Add(self.transmitbutton, 0, wx.ALIGN_CENTER | wx.ALL, 5)
+        sizerboxTransmitButton.Add(
+            self.transmitbutton, 0, wx.ALIGN_CENTER | wx.ALL, 5)
         sizerboxTransmitButton.Add([20, 20], 0, wx.ALIGN_CENTER | wx.ALL, 5)
 
         sizerPanel = wx.BoxSizer(wx.VERTICAL)
