@@ -5,7 +5,7 @@ using py2exe. Run: python.exe setup.py py2exe, to build executable file.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -30,15 +30,12 @@ import py2exe
 
 from smartcard.wx import ICO_SMARTCARD, ICO_READER
 
-Mydata_files = [('images', ['images/mysmartcard.ico', ICO_SMARTCARD, ICO_READER ])]
-
-
-setup(  windows=['apdumanager.py'],
-        data_files = Mydata_files,
-        options =
-        {
-            "py2exe":{"dll_excludes":["MSVCP90.dll"]}
-        }
-    )
+Mydata_files = [('images',
+                 ['images/mysmartcard.ico',
+                  ICO_SMARTCARD, ICO_READER])]
 
 
+setup(windows=['apdumanager.py'],
+    data_files=Mydata_files,
+    options={"py2exe": {"dll_excludes": ["MSVCP90.dll"]}}
+)
