@@ -4,7 +4,7 @@ Simple smart card monitoring application.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -27,10 +27,12 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 import os.path
 import sys
 from smartcard.wx.SimpleSCardApp import *
-from smartcard.wx.SimpleSCardAppEventObserver import SimpleSCardAppEventObserver
+from smartcard.wx.SimpleSCardAppEventObserver import \
+    SimpleSCardAppEventObserver
 
 ID_TEXT = 10000
 
+
 def we_are_frozen():
     """Returns whether we are frozen via py2exe.
     This will affect how we find out where we are located.
@@ -43,11 +45,11 @@ def module_path():
     """ This will get us the program's directory,
     even if we are frozen using py2exe. From WhereAmI page on py2exe wiki."""
 
-
     if we_are_frozen():
-        return os.path.dirname( unicode(sys.executable, sys.getfilesystemencoding( )) )
+        return os.path.dirname(
+                unicode(sys.executable, sys.getfilesystemencoding()))
 
-    return os.path.dirname(unicode(__file__, sys.getfilesystemencoding( )))
+    return os.path.dirname(unicode(__file__, sys.getfilesystemencoding()))
 
 
 class SamplePanel(wx.Panel, SimpleSCardAppEventObserver):
@@ -67,7 +69,8 @@ class SamplePanel(wx.Panel, SimpleSCardAppEventObserver):
         sizer.Add([20, 20], 0, wx.ALIGN_CENTER | wx.ALL, 5)
         sizer.Add([20, 20], 0, wx.ALIGN_CENTER | wx.ALL, 5)
 
-        self.feedbacktext = wx.StaticText(self, ID_TEXT, "", wx.DefaultPosition, wx.DefaultSize, 0)
+        self.feedbacktext = wx.StaticText(
+            self, ID_TEXT, "", wx.DefaultPosition, wx.DefaultSize, 0)
         sizer.Add(self.feedbacktext, 0, wx.ALIGN_LEFT | wx.ALL, 5)
 
         sizer.Add([20, 20], 0, wx.ALIGN_CENTER | wx.ALL, 5)
@@ -80,30 +83,35 @@ class SamplePanel(wx.Panel, SimpleSCardAppEventObserver):
 
     # callbacks from SimpleSCardAppEventObserver interface
     def OnActivateCard(self, card):
-        """Called when a card is activated by double-clicking on the card or reader tree control or toolbar.
+        """Called when a card is activated by double-clicking on the
+        card or reader tree control or toolbar.
         In this sample, we just connect to the card on the first activation."""
         SimpleSCardAppEventObserver.OnActivateCard(self, card)
-        self.feedbacktext.SetLabel('Activated card: ' + `card`)
+        self.feedbacktext.SetLabel('Activated card: ' + repr(card))
 
     def OnActivateReader(self, reader):
-        """Called when a reader is activated by double-clicking on the reader tree control or toolbar."""
+        """Called when a reader is activated by double-clicking on the
+        reader tree control or toolbar."""
         SimpleSCardAppEventObserver.OnActivateReader(self, reader)
-        self.feedbacktext.SetLabel('Activated reader: ' + `reader`)
+        self.feedbacktext.SetLabel('Activated reader: ' + repr(reader))
 
     def OnDeactivateCard(self, card):
-        """Called when a card is deactivated in the reader tree control or toolbar."""
+        """Called when a card is deactivated in the reader tree control
+        or toolbar."""
         SimpleSCardAppEventObserver.OnActivateCard(self, card)
-        self.feedbacktext.SetLabel('Deactivated card: ' + `card`)
+        self.feedbacktext.SetLabel('Deactivated card: ' + repr(card))
 
     def OnSelectCard(self, card):
-        """Called when a card is selected by clicking on the card or reader tree control or toolbar."""
+        """Called when a card is selected by clicking on the card or
+        reader tree control or toolbar."""
         SimpleSCardAppEventObserver.OnSelectCard(self, card)
-        self.feedbacktext.SetLabel('Selected card: ' + `card`)
+        self.feedbacktext.SetLabel('Selected card: ' + repr(card))
 
     def OnSelectReader(self, reader):
-        """Called when a reader is selected by clicking on the reader tree control or toolbar."""
+        """Called when a reader is selected by clicking on the reader
+        tree control or toolbar."""
         SimpleSCardAppEventObserver.OnSelectReader(self, reader)
-        self.feedbacktext.SetLabel('Selected reader: ' + `reader`)
+        self.feedbacktext.SetLabel('Selected reader: ' + repr(reader))
 
 
 def main(argv):
@@ -111,8 +119,8 @@ def main(argv):
         appname='A simple card monitoring tool',
         apppanel=SamplePanel,
         appstyle=TR_SMARTCARD | TR_READER,
-        appicon=os.path.join(module_path(), 'images', 'mysmartcard.ico'),
-        size=(800, 600))
+        appicon=os.path.join(
+            module_path(), 'images', 'mysmartcard.ico'), size=(800, 600))
     app.MainLoop()
 
 if __name__ == "__main__":
