@@ -3,7 +3,7 @@ Smartcard Session.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -29,7 +29,7 @@ from smartcard.PassThruCardService import PassThruCardService
 from smartcard.System import readers
 
 
-class Session:
+class Session(object):
     """The Session object enables programmers to transmit APDU to smartcards.
 
     This is an example of use of the Session object:
@@ -58,7 +58,7 @@ class Session:
         if readerName == None:
             if len(readers()) > 0:
                 self.reader = readers()[0]
-                self.readerName = `self.reader`
+                self.readerName = repr(self.reader)
             else:
                 raise NoReadersException()
 
@@ -68,7 +68,7 @@ class Session:
             for reader in readers():
                 if readerName == str(reader):
                     self.reader = reader
-                    self.readerName = `self.reader`
+                    self.readerName = repr(self.reader)
 
         try:
             self.reader
