@@ -4,7 +4,7 @@ Manages smartcard readers and reader groups.
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -44,7 +44,7 @@ def readers(groups=[]):
 def readergroups():
     """Returns the list of reader groups."""
 
-    return smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups()
+    return smartcard.pcsc.PCSCReaderGroups.PCSCReaderGroups().instance
 
 
 # for legacy only
