@@ -2,7 +2,7 @@
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -40,11 +40,7 @@ class pcscinnerreadergroups(innerreadergroups):
         self.unremovablegroups = ['SCard$DefaultReaders']
 
     def getreadergroups(self):
-        """ Returns the list of smartcard reader groups.
-
-        import smartcard
-        print smartcard.reader_groups()
-        """
+        """ Returns the list of smartcard reader groups."""
         innerreadergroups.getreadergroups(self)
 
         hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
@@ -61,55 +57,59 @@ class pcscinnerreadergroups(innerreadergroups):
     def addreadergroup(self, newgroup):
         """Add a reader group"""
 
-        innerreadergroups.addreadergroup(self, newgroup)
-
         hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
         if 0 != hresult:
-            raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to establish context: ' + \
+                SCardGetErrorMessage(hresult))
         try:
             hresult = SCardIntroduceReaderGroup(hcontext, newgroup)
             if 0 != hresult:
-                raise error, 'Unable to introduce reader group: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to introduce reader group: ' + \
+                    SCardGetErrorMessage(hresult))
+            else:
+                innerreadergroups.addreadergroup(self, newgroup)
+
         finally:
             hresult = SCardReleaseContext(hcontext)
             if 0 != hresult:
-                raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to release context: ' + \
+                    SCardGetErrorMessage(hresult))
 
     def removereadergroup(self, group):
         """Remove a reader group"""
 
-        innerreadergroups.removereadergroup(self, group)
-
         hresult, hcontext = SCardEstablishContext(SCARD_SCOPE_USER)
         if 0 != hresult:
-            raise error, 'Failed to establish context: ' + SCardGetErrorMessage(hresult)
+            raise error(
+                'Failed to establish context: ' + \
+                SCardGetErrorMessage(hresult))
         try:
             hresult = SCardForgetReaderGroup(hcontext, group)
             if hresult != 0:
-                raise error, 'Unable to forget reader group: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Unable to forget reader group: ' + \
+                    SCardGetErrorMessage(hresult))
+            else:
+                innerreadergroups.removereadergroup(self, group)
+
         finally:
             hresult = SCardReleaseContext(hcontext)
             if 0 != hresult:
-                raise error, 'Failed to release context: ' + SCardGetErrorMessage(hresult)
+                raise error(
+                    'Failed to release context: ' + \
+                    SCardGetErrorMessage(hresult))
 
 
 class PCSCReaderGroups(readergroups):
     """PCSC readers groups."""
 
-    """The single instance of __readergroups"""
-    instance = None
-
-    """Constructor: create a single instance of __readergroups on first call"""
-
     def __init__(self, initlist=None):
-        if None == PCSCReaderGroups.instance:
-            PCSCReaderGroups.instance = pcscinnerreadergroups(initlist)
-
-    """All operators redirected to inner class."""
-
-    def __getattr__(self, name):
-        return getattr(self.instance, name)
-
+        """Create a single instance of pcscinnerreadergroups on first call"""
+        self.innerclazz = pcscinnerreadergroups
+        readergroups.__init__(self, initlist)
 
 if __name__ == '__main__':
     print PCSCReaderGroups()
