@@ -10,7 +10,7 @@ The code to instanciate the reader Factory() has
 been updated to dynamically load the module with
 Robert Brewer ClassLoader.py.
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -34,7 +34,7 @@ from smartcard.ClassLoader import get_class
 from smartcard.pcsc.PCSCReader import PCSCReader
 
 
-class ReaderFactory:
+class ReaderFactory(object):
     """Class to create readers from reader type id."""
 
     factories = {}
@@ -48,7 +48,7 @@ class ReaderFactory:
         @param clazz:      the reader class name
         @param readername: the reader name
         """
-        if not ReaderFactory.factories.has_key(clazz):
+        if not clazz in ReaderFactory.factories:
             ReaderFactory.factories[clazz] = get_class(clazz).Factory()
         return ReaderFactory.factories[clazz].create(readername)
     createReader = staticmethod(createReader)
