@@ -2,7 +2,7 @@
 
 __author__ = "gemalto http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -37,7 +37,8 @@ class DeleteSCardDefaultReaderGroupException(SmartcardException):
     """Raised when trying to delete SCard$DefaultReaders reader group."""
 
     def __init__(self):
-        SmartcardException.__init__(self, 'SCard$DefaultReaders cannot be deleted')
+        SmartcardException.__init__(
+            self, 'SCard$DefaultReaders cannot be deleted')
 
 
 class innerreadergroups(ulist):
@@ -63,6 +64,12 @@ class innerreadergroups(ulist):
         """Called when a reader group is added."""
         self.removereadergroup(item)
 
+    def __iter__(self):
+        return ulist.__iter__(self)
+
+    def next(self):
+        return ulist.__next__(self)
+
     #
     # abstract methods implemented in subclasses
     #
@@ -75,11 +82,13 @@ class innerreadergroups(ulist):
         """Add a reader group"""
         if not isinstance(newgroup, type("")):
             raise BadReaderGroupException
+        self += newgroup
 
     def removereadergroup(self, group):
         """Remove a reader group"""
         if not isinstance(group, type("")):
             raise BadReaderGroupException
+        self.remove(group)
 
     def addreadertogroup(self, readername, groupname):
         """Add a reader to a reader group"""
@@ -90,17 +99,17 @@ class innerreadergroups(ulist):
         pass
 
 
-class readergroups:
+class readergroups(object):
     """ReadersGroups organizes smart card reader as groups."""
 
     """The single instance of __readergroups"""
     instance = None
-
-    """Constructor: create a single instance of __readergroups on first call"""
+    innerclazz = innerreadergroups
 
     def __init__(self, initlist=None):
+        """Create a single instance of innerreadergroups on first call"""
         if None == readergroups.instance:
-            readergroups.instance = innerreadergroups(initlist)
+            readergroups.instance = self.innerclazz(initlist)
 
     """All operators redirected to inner class."""
 
