@@ -1,5 +1,5 @@
 /*==============================================================================
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -187,7 +187,7 @@ BYTELIST* SCardHelper_PyByteListToBYTELIST(PyObject* source)
 build a Python byte list from a BYTELIST
 ==============================================================================*/
 {
-    int cBytes, x;
+    Py_ssize_t cBytes, x;
     BYTELIST* pbl;
 
 
@@ -232,7 +232,7 @@ build a Python byte list from a BYTELIST
         pbl->ab=NULL;
     }
     pbl->bAllocated=TRUE;
-    pbl->cBytes=cBytes;
+    pbl->cBytes=(SCARDDWORDARG)cBytes;
 
 
     for( x=0; x<cBytes; x++ )
@@ -375,7 +375,7 @@ GUIDLIST* SCardHelper_PyGuidListToGUIDLIST(PyObject* source)
 build a Python byte list from a GUIDLIST
 ==============================================================================*/
 {
-    int cBytes, cGuids, x;
+    Py_ssize_t cBytes, cGuids, x;
     //int iGuid, iByte;
     GUIDLIST* pgl;
     unsigned char* p;
@@ -421,7 +421,7 @@ build a Python byte list from a GUIDLIST
         return NULL;
     }
     pgl->bAllocated=TRUE;
-    pgl->cGuids=cGuids;
+    pgl->cGuids=(unsigned long)cGuids;
     pgl->hcontext=(unsigned long)NULL;
 
     // allocate GUIDs in GUID list
@@ -579,7 +579,7 @@ build a READERSTATELIST from a Python list of reader states
         return NULL;
     }
 
-    cRStates = PyList_Size(source);
+    cRStates = (SCARDDWORDARG)PyList_Size(source);
     for( x=0; x<cRStates; x++)
     {
         PyObject* o = PyList_GetItem( source, x );
@@ -727,7 +727,7 @@ builds a Python SCARDCONTEXT from a C SCARDCONTEXT
     #ifdef PCSCLITE
         oScardContext = PyLong_FromLong( (long)source );
     #else // !PCSCLITE
-        oScardContext = PyLong_FromUnsignedLong( (unsigned long)source );
+        oScardContext = PyLong_FromVoidPtr( (void*)source );
     #endif // PCSCLITE
 
     // append list to target
@@ -773,7 +773,7 @@ build a SCARDCONTEXT from a python SCARDCONTEXT
     #ifdef PCSCLITE
         scRet = PyLong_AsLong( source );
     #else // !PCSCLITE
-        scRet = PyLong_AsUnsignedLong( source );
+        scRet = PyLong_AsVoidPtr( source );
     #endif // PCSCLITE
 
     return scRet;
@@ -797,7 +797,7 @@ builds a Python SCARDHANDLE from a C SCARDHANDLE
     #ifdef PCSCLITE
         oScardHandle = PyLong_FromLong( (long)source );
     #else // !PCSCLITE
-        oScardHandle = PyLong_FromUnsignedLong( (unsigned long)source );
+        oScardHandle = PyLong_FromVoidPtr( (void*)source );
     #endif // PCSCLITE
 
     // append list to target
@@ -843,7 +843,7 @@ build a SCARDHANDLE from a python SCARDHANDLE
     #ifdef PCSCLITE
         scRet = PyLong_AsLong( source );
     #else // !PCSCLITE
-        scRet = PyLong_AsUnsignedLong( source );
+        scRet = PyLong_AsVoidPtr( source );
     #endif // PCSCLITE
 
     return scRet;
@@ -860,24 +860,24 @@ void SCardHelper_AppendSCardDwordArgToPyObject(
 builds a Python SCARDDWORDARG from a C SCARDDWORDARG
 ==============================================================================*/
 {
-    PyObject* oScardContext;
+    PyObject* oScardDword;
 
-    // create SCARDCONTEXT
+    // create SCARDDWORDARG
     #ifdef PCSCLITE
-        oScardContext = PyLong_FromLong( (long)source );
+        oScardDword = PyLong_FromLong( (long)source );
     #else // !PCSCLITE
-        oScardContext = PyLong_FromUnsignedLong( (unsigned long)source );
+        oScardDword = PyLong_FromUnsignedLong( (unsigned long)source );
     #endif // PCSCLITE
 
     // append list to target
     if( !*ptarget )
     {
-        *ptarget = oScardContext;
+        *ptarget = oScardDword;
     }
     else if( *ptarget == Py_None )
     {
         Py_DECREF(Py_None);
-        *ptarget = oScardContext;
+        *ptarget = oScardDword;
     }
     else
     {
@@ -888,8 +888,8 @@ builds a Python SCARDDWORDARG from a C SCARDDWORDARG
             PyList_Append(*ptarget,o2);
             Py_XDECREF(o2);
         }
-        PyList_Append(*ptarget,oScardContext);
-        Py_XDECREF(oScardContext);
+        PyList_Append(*ptarget,oScardDword);
+        Py_XDECREF(oScardDword);
     }
 }
 
@@ -983,7 +983,7 @@ Build a STRING from a Python string; the string is allocated and
 will have to be freed externally to the wrapper
 ==============================================================================*/
 {
-    unsigned long ulLength;
+    size_t ulLength;
     STRING* pstr=NULL;
 
     for(;;)
@@ -1128,7 +1128,7 @@ STRINGLIST* SCardHelper_PyStringListToStringList(PyObject* source)
 build a Python string list from a STRINGLIST
 ==============================================================================*/
 {
-    int cStrings, cChars, x;
+    Py_ssize_t cStrings, cChars, x;
     STRINGLIST* psl;
     char* p;
 
@@ -1172,7 +1172,7 @@ build a Python string list from a STRINGLIST
             return NULL;
         }
 
-        for( x=0, cChars=0, p=psl->ac; x<cStrings; x++ )
+        for( x=0, p=psl->ac; x<cStrings; x++ )
         {
             PyObject* o = PyList_GetItem(source, x);
             strcpy( p, PyString_AsString(o) );
