@@ -1,5 +1,5 @@
 /*==============================================================================
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -236,7 +236,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
     WINAPI _defaultSCARDISVALIDCONTEXT(
         IN      SCARDCONTEXT hContext)
     {
-		(void)hContext;
+        (void)hContext;
 
         return SCARD_E_NO_SERVICE;
     }
@@ -248,10 +248,10 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
         OUT LPBYTE pbAttr,
         IN OUT SCARDDWORDARG* pcbAttrLen)
     {
-		(void)hCard;
-		(void)dwAttrId;
-		(void)pbAttr;
-		(void)pcbAttrLen;
+        (void)hCard;
+        (void)dwAttrId;
+        (void)pbAttr;
+        (void)pcbAttrLen;
 
         return SCARD_E_NO_SERVICE;
     }
@@ -263,10 +263,10 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
         IN LPCBYTE pbAttr,
         IN SCARDDWORDARG cbAttrLen)
     {
-		(void)hCard;
-		(void)dwAttrId;
-		(void)pbAttr;
-		(void)cbAttrLen;
+        (void)hCard;
+        (void)dwAttrId;
+        (void)pbAttr;
+        (void)cbAttrLen;
 
         return SCARD_E_NO_SERVICE;
     }
@@ -448,7 +448,7 @@ static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDBEGINTRANSACTION(
     IN      SCARDHANDLE hCard)
 {
-	(void)hCard;
+    (void)hCard;
 
     return SCARD_E_NO_SERVICE;
 }
@@ -457,16 +457,7 @@ static WINSCARDAPI SCARDRETCODE
 WINAPI _defaultSCARDCANCEL(
     IN      SCARDCONTEXT hContext)
 {
-	(void)hContext;
-
-    return SCARD_E_NO_SERVICE;
-}
-
-static WINSCARDAPI SCARDRETCODE
-WINAPI _defaultSCARDCANCELTRANSACTION(
-    IN      SCARDHANDLE hCard)
-{
-	(void)hCard;
+    (void)hContext;
 
     return SCARD_E_NO_SERVICE;
 }
@@ -651,7 +642,6 @@ WINAPI _defaultSCARDTRANSMIT(
 
 SCARDBEGINTRANSACTION           mySCardBeginTransaction             = _defaultSCARDBEGINTRANSACTION;
 SCARDCANCEL                     mySCardCancel                       = _defaultSCARDCANCEL;
-SCARDCANCELTRANSACTION          mySCardCancelTransaction            = _defaultSCARDCANCELTRANSACTION;
 SCARDCONNECTA                   mySCardConnectA                     = _defaultSCARDCONNECTA;
 SCARDCONTROL                    mySCardControl                      = _defaultSCARDCONTROL;
 SCARDDISCONNECT                 mySCardDisconnect                   = _defaultSCARDDISCONNECT;
@@ -695,7 +685,6 @@ long winscard_init(void)
                 GETPROCADDRESS( SCARDACCESSSTARTEDEVENT         , SCardAccessStartedEvent );
                 GETPROCADDRESS( SCARDBEGINTRANSACTION           , SCardBeginTransaction );
                 GETPROCADDRESS( SCARDCANCEL                     , SCardCancel );
-                GETPROCADDRESS( SCARDCANCELTRANSACTION          , SCardCancelTransaction );
                 GETPROCADDRESS( SCARDCONNECTA                   , SCardConnectA );
                 GETPROCADDRESS( SCARDCONTROL                    , SCardControl );
                 GETPROCADDRESS( SCARDDISCONNECT                 , SCardDisconnect );
@@ -769,7 +758,6 @@ long winscard_init(void)
                 lRetCode=SCARD_S_SUCCESS;
                 GETPROCADDRESS( SCARDBEGINTRANSACTION  , SCardBeginTransaction  , SCardBeginTransaction  );
                 GETPROCADDRESS( SCARDCANCEL            , SCardCancel            , SCardCancel );
-                GETPROCADDRESS( SCARDCANCELTRANSACTION , SCardCancelTransaction , SCardCancelTransaction );
                 GETPROCADDRESS( SCARDCONNECTA          , SCardConnectA          , SCardConnect           );
                 GETPROCADDRESS( SCARDDISCONNECT        , SCardDisconnect        , SCardDisconnect        );
                 GETPROCADDRESS( SCARDENDTRANSACTION    , SCardEndTransaction    , SCardEndTransaction    );
