@@ -1,8 +1,9 @@
-"""The error checking chain is a list of status word (sw1, sw2) error check strategies.
+"""The error checking chain is a list of status word
+(sw1, sw2) error check strategies.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -25,7 +26,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 from sys import exc_info
 
 
-class ErrorCheckingChain:
+class ErrorCheckingChain(object):
     """The error checking chain is a list of response apdu status word
     (sw1, sw2) error check strategies. Each strategy in the chain is
     called until an error is detected. A L{smartcard.sw.SWException}
