@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -70,7 +70,7 @@ class ISO7816_4_SW1ErrorChecker(ErrorChecker):
         @param data:       apdu response data
         @param sw1, sw2:   apdu data status words
         """
-        if iso7816_4SW1.has_key(sw1):
+        if sw1 in iso7816_4SW1:
             exception = iso7816_4SW1[sw1]
             raise exception(data, sw1, sw2)
 
