@@ -2,7 +2,7 @@
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -104,7 +104,7 @@ class op21_ErrorChecker(ErrorChecker):
         @param sw1, sw2:   apdu data status words
 
         Derived classes must raise a L{smartcard.sw.SWException} upon error."""
-        if op21_SW.has_key(sw1):
+        if sw1 in op21_SW:
             exception, sw2dir = op21_SW[sw1]
             if type(sw2dir) == type({}):
                 try:
