@@ -6,7 +6,7 @@ The generated configuration is store in local_config.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -60,7 +60,7 @@ def checklocalconfig():
             expectedATRs.append([])
     f.write('expectedATRs = ')
     #for atr in expectedATRs: print `toHexString(atr)`
-    f.write(`expectedATRs` + '\n')
+    f.write(repr(expectedATRs) + '\n')
 
     f.write('expectedATRinReader = {}\n')
     f.write('for i in xrange(len(expectedReaders)):\n')
@@ -68,7 +68,8 @@ def checklocalconfig():
 
     f.write('expectedReaderForATR = {}\n')
     f.write('for i in xrange(len(expectedReaders)):\n')
-    f.write('    expectedReaderForATR[toHexString(expectedATRs[i])] = expectedReaders[i]\n')
+    f.write('    expectedReaderForATR[toHexString(expectedATRs[i])] = ' + \
+                    'expectedReaders[i]\n')
 
     f.write('expectedReaderGroups = [\'SCard$DefaultReaders\']\n')
 
