@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -37,7 +37,8 @@ import sys
 sys.path += ['..']
 
 try:
-    from local_config import expectedATRs, expectedReaders, expectedReaderGroups, expectedATRinReader
+    from local_config import expectedATRs, expectedReaders
+    from local_config import expectedReaderGroups, expectedATRinReader
 except:
     print 'execute test suite first to generate the local_config.py file'
     sys.exit()
@@ -51,6 +52,16 @@ from smartcard.System import readers
 class testcase_Card(unittest.TestCase):
     """Test case for smartcard.Card."""
 
+    def testcase_CardDictionary(self):
+        """Create a dictionnary with Card keys"""
+        mydict = {}
+        for reader in readers():
+            card = Card(reader, expectedATRinReader[str(reader)])
+            mydict[card] = reader
+
+        for card in mydict.keys():
+            self.assert_(str(card.reader) in expectedReaders)
+
     def testcase_Card_FromReaders(self):
         """Create a Card from Readers and test that the response
         to SELECT DF_TELECOM has two bytes."""
@@ -65,7 +76,8 @@ class testcase_Card(unittest.TestCase):
                 response, sw1, sw2 = cc.transmit(SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "9f 20": 2, "6e 0": 3}
                 self.assertEquals([], response)
-                self.assert_(expectedSWs.has_key("%x %x" % (sw1, sw2)) or "9f" == "%x" % sw1)
+                self.assert_(
+                    "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
 
@@ -83,7 +95,8 @@ class testcase_Card(unittest.TestCase):
                 response, sw1, sw2 = cc.transmit(SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "9f 20": 2, "6e 0": 3}
                 self.assertEquals([], response)
-                self.assert_(expectedSWs.has_key("%x %x" % (sw1, sw2)) or "9f" == "%x" % sw1)
+                self.assert_(
+                    "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
             else:
                 self.assertRaises(NoCardException, cc.connect)
 
