@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -39,7 +39,8 @@ import sys
 sys.path += ['..']
 
 try:
-    from local_config import expectedATRs, expectedReaders, expectedReaderGroups, expectedATRinReader
+    from local_config import expectedATRs, expectedReaders
+    from local_config import expectedReaderGroups, expectedATRinReader
 except:
     print 'execute test suite first to generate the local_config.py file'
     sys.exit()
@@ -63,7 +64,7 @@ class printobserver(CardObserver):
             foundcards[toHexString(card.atr)] = 1
         for atr in expectedATRs:
             if [] != atr and {} != foundcards:
-                self.testcase.assert_(foundcards.has_key(toHexString(atr)))
+                self.testcase.assert_(toHexString(atr) in foundcards)
 
 
 class testthread(threading.Thread):
