@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -36,7 +36,8 @@ import sys
 sys.path += ['..']
 
 try:
-    from local_config import expectedATRs, expectedReaders, expectedReaderGroups, expectedATRinReader
+    from local_config import expectedATRs, expectedReaders
+    from local_config import expectedReaderGroups, expectedATRinReader
 except:
     print 'execute test suite first to generate the local_config.py file'
     sys.exit()
@@ -60,10 +61,12 @@ class testcase_CardService(unittest.TestCase):
                 cc = reader.createConnection()
                 cs = CardService(cc)
                 cs.connection.connect()
-                response, sw1, sw2 = cs.connection.transmit(SELECT + DF_TELECOM)
+                response, sw1, sw2 = cs.connection.transmit(
+                    SELECT + DF_TELECOM)
                 expectedSWs = {"9f 1a": 1, "6e 0": 2, "9f 20": 3, "9f 22": 4}
                 self.assertEquals([], response)
-                self.assert_(expectedSWs.has_key("%x %x" % (sw1, sw2)) or "9f" == "%x" % sw1)
+                self.assert_(
+                    "%x %x" % (sw1, sw2) in expectedSWs or "9f" == "%x" % sw1)
 
 
 def suite():
