@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -47,7 +47,8 @@ import smartcard.sw.SWExceptions
 
 
 try:
-    from local_config import expectedATRs, expectedReaders, expectedReaderGroups, expectedATRinReader
+    from local_config import expectedATRs, expectedReaders
+    from local_config import expectedReaderGroups, expectedATRinReader
 except:
     print 'execute test suite first to generate the local_config.py file'
     sys.exit()
@@ -117,7 +118,7 @@ class testcase_ErrorChecking(unittest.TestCase):
         for sw1 in range(0x00, 0xff + 1):
             sw2range = []
             exception = None
-            if tiso7816_4SW1.has_key(sw1):
+            if sw1 in tiso7816_4SW1:
                 exception = tiso7816_4SW1[sw1]
             for sw2 in range(0x00, 0xff + 1):
                 if None != exception:
@@ -130,13 +131,20 @@ class testcase_ErrorChecking(unittest.TestCase):
         ecs = ISO7816_4ErrorChecker()
 
         tiso7816_4SW = {
-            0x62: (smartcard.sw.SWExceptions.WarningProcessingException, [0x00, 0x81, 0x82, 0x83, 0x84, 0xff]),
-            0x63: (smartcard.sw.SWExceptions.WarningProcessingException, [0x00, 0x81] + range(0xc0, 0xcf + 1)),
-            0x64: (smartcard.sw.SWExceptions.ExecutionErrorException, [0x00]),
-            0x67: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
-            0x68: (smartcard.sw.SWExceptions.CheckingErrorException, [0x81, 0x82]),
-            0x69: (smartcard.sw.SWExceptions.CheckingErrorException, range(0x81, 0x88 + 1)),
-            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException, range(0x80, 0x88 + 1)),
+            0x62: (smartcard.sw.SWExceptions.WarningProcessingException,
+                    [0x00, 0x81, 0x82, 0x83, 0x84, 0xff]),
+            0x63: (smartcard.sw.SWExceptions.WarningProcessingException,
+                    [0x00, 0x81] + range(0xc0, 0xcf + 1)),
+            0x64: (smartcard.sw.SWExceptions.ExecutionErrorException,
+                    [0x00]),
+            0x67: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x00]),
+            0x68: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x81, 0x82]),
+            0x69: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    range(0x81, 0x88 + 1)),
+            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    range(0x80, 0x88 + 1)),
             0x6B: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
             0x6D: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
             0x6E: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
@@ -145,7 +153,7 @@ class testcase_ErrorChecking(unittest.TestCase):
 
         for sw1 in range(0x00, 0xff + 1):
             sw2range = []
-            if tiso7816_4SW.has_key(sw1):
+            if sw1 in tiso7816_4SW:
                 exception, sw2range = tiso7816_4SW[sw1]
             for sw2 in range(0x00, 0xff + 1):
                 if sw2 in sw2range:
@@ -158,18 +166,25 @@ class testcase_ErrorChecking(unittest.TestCase):
         ecs = ISO7816_8ErrorChecker()
 
         tiso7816_8SW = {
-            0x63: (smartcard.sw.SWExceptions.WarningProcessingException, [0x00] + range(0xc0, 0xcf + 1)),
-            0x65: (smartcard.sw.SWExceptions.ExecutionErrorException, [0x81]),
-            0x66: (smartcard.sw.SWExceptions.SecurityRelatedException, [0x00, 0x87, 0x88]),
-            0x67: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
-            0x68: (smartcard.sw.SWExceptions.CheckingErrorException, [0x83, 0x84]),
-            0x69: (smartcard.sw.SWExceptions.CheckingErrorException, range(0x82, 0x85 + 1)),
-            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException, [0x81, 0x82, 0x86, 0x88]),
+            0x63: (smartcard.sw.SWExceptions.WarningProcessingException,
+                    [0x00] + range(0xc0, 0xcf + 1)),
+            0x65: (smartcard.sw.SWExceptions.ExecutionErrorException,
+                    [0x81]),
+            0x66: (smartcard.sw.SWExceptions.SecurityRelatedException,
+                    [0x00, 0x87, 0x88]),
+            0x67: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x00]),
+            0x68: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x83, 0x84]),
+            0x69: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    range(0x82, 0x85 + 1)),
+            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x81, 0x82, 0x86, 0x88]),
         }
 
         for sw1 in range(0x00, 0xff + 1):
             sw2range = []
-            if tiso7816_8SW.has_key(sw1):
+            if sw1 in tiso7816_8SW:
                 exception, sw2range = tiso7816_8SW[sw1]
             for sw2 in range(0x00, 0xff + 1):
                 if sw2 in sw2range:
@@ -182,15 +197,19 @@ class testcase_ErrorChecking(unittest.TestCase):
         ecs = ISO7816_9ErrorChecker()
 
         tiso7816_9SW = {
-            0x62: (smartcard.sw.SWExceptions.WarningProcessingException, [0x82]),
-            0x64: (smartcard.sw.SWExceptions.ExecutionErrorException, [0x00]),
-            0x69: (smartcard.sw.SWExceptions.CheckingErrorException, [0x82]),
-            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException, [0x80, 0x84, 0x89, 0x8A]),
+            0x62: (smartcard.sw.SWExceptions.WarningProcessingException,
+                    [0x82]),
+            0x64: (smartcard.sw.SWExceptions.ExecutionErrorException,
+                    [0x00]),
+            0x69: (smartcard.sw.SWExceptions.CheckingErrorException, [
+                    0x82]),
+            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x80, 0x84, 0x89, 0x8A]),
         }
 
         for sw1 in range(0x00, 0xff + 1):
             sw2range = []
-            if tiso7816_9SW.has_key(sw1):
+            if sw1 in tiso7816_9SW:
                 exception, sw2range = tiso7816_9SW[sw1]
             for sw2 in range(0x00, 0xff + 1):
                 if sw2 in sw2range:
@@ -203,21 +222,31 @@ class testcase_ErrorChecking(unittest.TestCase):
         ecs = op21_ErrorChecker()
 
         top21_SW = {
-            0x62: (smartcard.sw.SWExceptions.WarningProcessingException, [0x83]),
-            0x63: (smartcard.sw.SWExceptions.WarningProcessingException, [0x00]),
-            0x64: (smartcard.sw.SWExceptions.ExecutionErrorException, [0x00]),
-            0x65: (smartcard.sw.SWExceptions.ExecutionErrorException, [0x81]),
-            0x67: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
-            0x69: (smartcard.sw.SWExceptions.CheckingErrorException, [0x82, 0x85]),
-            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException, [0x80, 0x81, 0x82, 0x84, 0x86, 0x88]),
-            0x6D: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
-            0x6E: (smartcard.sw.SWExceptions.CheckingErrorException, [0x00]),
-            0x94: (smartcard.sw.SWExceptions.CheckingErrorException, [0x84, 0x85]),
+            0x62: (smartcard.sw.SWExceptions.WarningProcessingException, [
+                    0x83]),
+            0x63: (smartcard.sw.SWExceptions.WarningProcessingException,
+                    [0x00]),
+            0x64: (smartcard.sw.SWExceptions.ExecutionErrorException, [
+                    0x00]),
+            0x65: (smartcard.sw.SWExceptions.ExecutionErrorException, [
+                    0x81]),
+            0x67: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x00]),
+            0x69: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x82, 0x85]),
+            0x6A: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x80, 0x81, 0x82, 0x84, 0x86, 0x88]),
+            0x6D: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x00]),
+            0x6E: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x00]),
+            0x94: (smartcard.sw.SWExceptions.CheckingErrorException,
+                    [0x84, 0x85]),
         }
 
         for sw1 in range(0x00, 0xff + 1):
             sw2range = []
-            if top21_SW.has_key(sw1):
+            if sw1 in top21_SW:
                 exception, sw2range = top21_SW[sw1]
             for sw2 in range(0x00, 0xff + 1):
                 if sw2 in sw2range:
@@ -234,7 +263,9 @@ class testcase_ErrorChecking(unittest.TestCase):
         # ISO7816-4 is answering first on the next, i.e
         # WarningProcessingException
         for sw2 in [0x00, 0x81] + range(0xc0, 0xcf + 1):
-            self.assertRaises(smartcard.sw.SWExceptions.WarningProcessingException, errorchain[0], [], 0x63, sw2)
+            self.assertRaises(
+                smartcard.sw.SWExceptions.WarningProcessingException,
+                errorchain[0], [], 0x63, sw2)
 
     def testcase_Test_ISO78164_ErrorCheckingChain(self):
         """Test error chain with Test checker followed by ISO7816-4 checker."""
@@ -250,22 +281,38 @@ class testcase_ErrorChecking(unittest.TestCase):
         """Test correct exception error message."""
         ecs = ISO7816_4ErrorChecker()
 
-        e = self.failUnlessRaises(smartcard.sw.SWExceptions.CheckingErrorException, ecs, [], 0x69, 0x85)
-        self.assertEquals(str(e), "'Status word exception: checking error - Conditions of use not satisfied!'")
+        e = self.failUnlessRaises(
+            smartcard.sw.SWExceptions.CheckingErrorException,
+            ecs,
+            [],
+            0x69,
+            0x85)
+        self.assertEquals(
+            str(e),
+            "'Status word exception: checking error - " + \
+             "Conditions of use not satisfied!'")
 
-        e = self.failUnlessRaises(smartcard.sw.SWExceptions.CheckingErrorException, ecs, [], 0x6b, 0x00)
-        self.assertEquals(str(e), "'Status word exception: checking error - Incorrect parameters P1-P2!'")
+        e = self.failUnlessRaises(
+            smartcard.sw.SWExceptions.CheckingErrorException,
+            ecs,
+            [],
+            0x6b,
+            0x00)
+        self.assertEquals(
+            str(e), "'Status word exception: checking error - " + \
+            "Incorrect parameters P1-P2!'")
 
     def testcase_ISO78164_Test_ErrorCheckingChain_filtering(self):
         """Test error chain with ISO7816-4 checker followed by Test checker."""
         errorchain = []
         errorchain = [ErrorCheckingChain(errorchain, ISO7816_8ErrorChecker()),
                      ErrorCheckingChain(errorchain, ISO7816_4ErrorChecker()),
-                     ErrorCheckingChain(errorchain, ISO7816_4_SW1ErrorChecker())]
-
+                     ErrorCheckingChain(
+                         errorchain, ISO7816_4_SW1ErrorChecker())]
 
         # don't care about Warning Exceptions
-        errorchain[0].addFilterException(smartcard.sw.SWExceptions.WarningProcessingException)
+        errorchain[0].addFilterException(
+            smartcard.sw.SWExceptions.WarningProcessingException)
 
         for sw2 in range(0x00, 0xff):
 
@@ -273,7 +320,12 @@ class testcase_ErrorChecking(unittest.TestCase):
             errorchain[0]([], 0x62, sw2)
             errorchain[0]([], 0x63, sw2)
             # should raise
-            self.assertRaises(smartcard.sw.SWExceptions.ExecutionErrorException, errorchain[0], [], 0x64, sw2)
+            self.assertRaises(
+                smartcard.sw.SWExceptions.ExecutionErrorException,
+                errorchain[0],
+                [],
+                0x64,
+                sw2)
 
 
 def suite():
