@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -26,13 +26,14 @@ along with pyscard; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 """
 
+import platform
 import unittest
-
-from smartcard.reader.ReaderGroups import readergroups
+from smartcard.System import readergroups
 from smartcard.scard import resourceManager
 
 
-if 'winscard' == resourceManager:
+if 'winscard' == resourceManager and \
+    -1 == platform.platform().find('Windows-7'):
 
     class testcase_readergroups(unittest.TestCase):
         """Test smartcard framework readersgroups."""
@@ -53,7 +54,8 @@ if 'winscard' == resourceManager:
 
             # add pinpad a second time and biometric once
             groups = groups + [self.biogroup, self.pinpadgroup]
-            self.assertEquals(groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
+            self.assertEquals(
+                groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
 
             # clean-up
             groups.remove(self.biogroup)
@@ -72,7 +74,8 @@ if 'winscard' == resourceManager:
 
             # add pinpad a second time and biometric once
             groups += [self.biogroup, self.pinpadgroup]
-            self.assertEquals(groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
+            self.assertEquals(
+                groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
 
             # clean-up
             groups.remove(self.biogroup)
@@ -93,9 +96,11 @@ if 'winscard' == resourceManager:
             self.assert_(isinstance(groups, type(readergroups())))
 
             # add pinpad a tiwce and biometric once
-            zgroups = [self.pinpadgroup, self.biogroup, self.pinpadgroup] + groups
+            zgroups = \
+                [self.pinpadgroup, self.biogroup, self.pinpadgroup] + groups
             self.assertEquals(groups, groupssnapshot)
-            self.assertEquals(zgroups, groupssnapshot + [self.pinpadgroup, self.biogroup])
+            self.assertEquals(
+                zgroups, groupssnapshot + [self.pinpadgroup, self.biogroup])
             self.assert_(isinstance(zgroups, type([])))
             self.assert_(isinstance(groups, type(readergroups())))
 
@@ -116,7 +121,8 @@ if 'winscard' == resourceManager:
 
             # add biometric once
             groups.append(self.biogroup)
-            self.assertEquals(groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
+            self.assertEquals(
+                groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
 
             # clean-up
             groups.remove(self.biogroup)
@@ -139,7 +145,8 @@ if 'winscard' == resourceManager:
 
             # add biometric once
             groups.insert(1, self.biogroup)
-            self.assertEquals(groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
+            self.assertEquals(
+                groups, groupssnapshot + [self.pinpadgroup, self.biogroup])
 
             # clean-up
             groups.remove(self.biogroup)
