@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -85,7 +85,7 @@ class readerInsertionThread(threading.Thread):
                 mutexvreaders.acquire()
                 if newreader not in virtualreaders:
                     virtualreaders.append(newreader)
-                    if insertedreaderstats.has_key(newreader):
+                    if newreader in insertedreaderstats:
                         insertedreaderstats[newreader] += 1
                     else:
                         insertedreaderstats[newreader] = 1
@@ -109,7 +109,7 @@ class readerRemovalThread(threading.Thread):
                 if virtualreaders:
                     oldreader = random.choice(virtualreaders)
                     virtualreaders.remove(oldreader)
-                    if removedreaderstats.has_key(oldreader):
+                    if oldreader in removedreaderstats:
                         removedreaderstats[oldreader] += 1
                     else:
                         removedreaderstats[oldreader] = 1
@@ -130,12 +130,12 @@ class countobserver(ReaderObserver):
     def update(self, observable, (addedreaders, removedreaders)):
         self.countnotified += 1
         for newreader in addedreaders:
-            if self.insertedreaderstats.has_key(newreader):
+            if newreader in self.insertedreaderstats:
                 self.insertedreaderstats[newreader] += 1
             else:
                 self.insertedreaderstats[newreader] = 1
         for oldreader in removedreaders:
-            if self.removedreaderstats.has_key(oldreader):
+            if oldreader in self.removedreaderstats:
                 self.removedreaderstats[oldreader] += 1
             else:
                 self.removedreaderstats[oldreader] = 1
@@ -174,14 +174,10 @@ class testcase_readermonitorstress(unittest.TestCase):
         time.sleep(2 * period)
 
         for observer in observers:
-            #print observer.obsindex, observer.insertedreaderstats==insertedreaderstats, observer.countnotified
-            #print observer.obsindex, observer.removedreaderstats==removedreaderstats, observer.countnotified
-            #print observer.insertedreaderstats
-            #print insertedreaderstats
-            #print observer.removedreaderstats
-            #print removedreaderstats
-            self.assertEquals(observer.insertedreaderstats, insertedreaderstats)
-            self.assertEquals(observer.removedreaderstats, removedreaderstats)
+            self.assertEquals(
+                observer.insertedreaderstats, insertedreaderstats)
+            self.assertEquals(
+                observer.removedreaderstats, removedreaderstats)
 
 
 def suite():
