@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -36,7 +36,8 @@ import sys
 sys.path += ['..']
 
 try:
-    from local_config import expectedATRs, expectedReaders, expectedReaderGroups, expectedATRinReader
+    from local_config import expectedATRs, expectedReaders
+    from local_config import expectedReaderGroups, expectedATRinReader
 except:
     print 'execute test suite first to generate the local_config.py file'
     sys.exit()
@@ -58,28 +59,35 @@ class testcase_readers(unittest.TestCase):
         for reader in readers():
             foundreaders[str(reader)] = 1
         for reader in expectedReaders:
-            self.assert_(foundreaders.has_key(reader))
+            self.assert_(reader in foundreaders)
+
+    def testcase_hashreaders(self):
+        foundreaders = {}
+        for reader in readers():
+            foundreaders[reader] = 1
+        for reader in foundreaders.keys():
+            self.assert_(reader in readers())
 
     def testcase_legacyreaders(self):
         foundreaders = {}
         for reader in listReaders():
             foundreaders[reader] = 1
         for reader in expectedReaders:
-            self.assert_(foundreaders.has_key(reader))
+            self.assert_(reader in foundreaders)
 
     def testcase_readers_in_readergroup(self):
         foundreaders = {}
         for reader in readers(['SCard$DefaultReaders']):
             foundreaders[str(reader)] = 1
         for reader in expectedReaders:
-            self.assert_(foundreaders.has_key(reader))
+            self.assert_(reader in foundreaders)
 
     def testcase_readers_in_readergroup_empty(self):
         foundreaders = {}
         for reader in readers([]):
             foundreaders[str(reader)] = 1
         for reader in expectedReaders:
-            self.assert_(foundreaders.has_key(reader))
+            self.assert_(reader in foundreaders)
 
     if 'winscard' == resourceManager:
 
@@ -88,7 +96,7 @@ class testcase_readers(unittest.TestCase):
             for reader in readers(['dummy$group']):
                 foundreaders[reader] = 1
             for reader in expectedReaders:
-                self.assert_(not foundreaders.has_key(reader))
+                self.assert_(not reader in foundreaders)
             self.assertEquals(0, len(foundreaders))
 
     def testcase_readergroups(self):
@@ -96,7 +104,7 @@ class testcase_readers(unittest.TestCase):
         for readergroup in readergroups():
             foundreadergroups[readergroup] = 1
         for readergroup in expectedReaderGroups:
-            self.assert_(foundreadergroups.has_key(readergroup))
+            self.assert_(readergroup in foundreadergroups)
 
 
 def suite():
