@@ -6,7 +6,7 @@ thru testsuite_framework.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -36,7 +36,8 @@ import sys
 sys.path += ['..']
 
 try:
-    from local_config import expectedATRs, expectedReaders, expectedReaderGroups, expectedATRinReader
+    from local_config import expectedATRs, expectedReaders
+    from local_config import expectedReaderGroups, expectedATRinReader
 except:
     print 'execute test suite first to generate the local_config.py file'
     sys.exit()
@@ -52,7 +53,7 @@ if 'winscard' == resourceManager:
         """Test smartcard framework readers factory methods"""
 
         def setUp(self):
-            groups = PCSCReaderGroups()
+            groups = PCSCReaderGroups().instance
             try:
                 groups.remove('Pinpad$Readers')
                 groups.remove('Biometric$Readers')
@@ -61,8 +62,8 @@ if 'winscard' == resourceManager:
 
         def testcase_add(self):
             """Test for groups=groups+newgroups"""
-            groupssnapshot = list(PCSCReaderGroups())
-            groups = PCSCReaderGroups()
+            groupssnapshot = list(PCSCReaderGroups().instance)
+            groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups = groups + newgroup
             self.assertEquals(groups, groupssnapshot + [newgroup])
@@ -70,8 +71,8 @@ if 'winscard' == resourceManager:
 
         def testcase_addlist(self):
             """Test for groups=groups+[newgroups]"""
-            groupssnapshot = list(PCSCReaderGroups())
-            groups = PCSCReaderGroups()
+            groupssnapshot = list(PCSCReaderGroups().instance)
+            groups = PCSCReaderGroups().instance
             newgroups = ['Pinpad$Readers', 'Biometric$Readers']
             groups = groups + newgroups
             self.assertEquals(groups, groupssnapshot + newgroups)
@@ -80,8 +81,8 @@ if 'winscard' == resourceManager:
 
         def testcase_iadd(self):
             """Test for groups+=newgroup"""
-            groupssnapshot = list(PCSCReaderGroups())
-            groups = PCSCReaderGroups()
+            groupssnapshot = list(PCSCReaderGroups().instance)
+            groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups += newgroup
             self.assertEquals(groups, groupssnapshot + [newgroup])
@@ -89,8 +90,8 @@ if 'winscard' == resourceManager:
 
         def testcase_iaddlist(self):
             """Test for groups+=[newgroups]"""
-            groupssnapshot = list(PCSCReaderGroups())
-            groups = PCSCReaderGroups()
+            groupssnapshot = list(PCSCReaderGroups().instance)
+            groups = PCSCReaderGroups().instance
             newgroups = ['Pinpad$Readers', 'Biometric$Readers']
             groups += newgroups
             self.assertEquals(groups, groupssnapshot + newgroups)
@@ -99,8 +100,8 @@ if 'winscard' == resourceManager:
 
         def testcase_append(self):
             """Test for groups.append(newgroup)"""
-            groupssnapshot = list(PCSCReaderGroups())
-            groups = PCSCReaderGroups()
+            groupssnapshot = list(PCSCReaderGroups().instance)
+            groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.append(newgroup)
             self.assertEquals(groups, groupssnapshot + [newgroup])
@@ -108,8 +109,8 @@ if 'winscard' == resourceManager:
 
         def testcase_insert(self):
             """Test for groups.insert(newgroup)"""
-            groupssnapshot = list(PCSCReaderGroups())
-            groups = PCSCReaderGroups()
+            groupssnapshot = list(PCSCReaderGroups().instance)
+            groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.insert(0, newgroup)
             self.assertEquals(groups, [newgroup] + groupssnapshot)
@@ -117,8 +118,8 @@ if 'winscard' == resourceManager:
 
         def testcase_removereadergroup_pop(self):
             """Test for groups.pop()"""
-            groupssnapshot = list(PCSCReaderGroups())
-            groups = PCSCReaderGroups()
+            groupssnapshot = list(PCSCReaderGroups().instance)
+            groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.insert(0, newgroup)
             self.assertEquals(groups, [newgroup] + groupssnapshot)
@@ -127,23 +128,29 @@ if 'winscard' == resourceManager:
 
         def testcase_addreadertogroup(self):
             """Test for adding readers to group"""
-            groups = PCSCReaderGroups()
+            groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.insert(0, newgroup)
             for r in PCSCReader.readers('SCard$DefaultReaders'):
                 r.addtoreadergroup(newgroup)
-            self.assertEquals(PCSCReader.readers('SCard$DefaultReaders'), PCSCReader.readers(newgroup))
+            self.assertEquals(
+                PCSCReader.readers(
+                    'SCard$DefaultReaders'),
+                PCSCReader.readers(newgroup))
             groups.pop(0)
             self.assertEquals([], PCSCReader.readers(newgroup))
 
         def testcase_removereaderfromgroup(self):
             """Test for removing readers from group"""
-            groups = PCSCReaderGroups()
+            groups = PCSCReaderGroups().instance
             newgroup = 'Pinpad$Readers'
             groups.insert(0, newgroup)
             for r in PCSCReader.readers('SCard$DefaultReaders'):
                 r.addtoreadergroup(newgroup)
-            self.assertEquals(PCSCReader.readers('SCard$DefaultReaders'), PCSCReader.readers(newgroup))
+            self.assertEquals(
+                PCSCReader.readers(
+                    'SCard$DefaultReaders'),
+                PCSCReader.readers(newgroup))
             for r in PCSCReader.readers('SCard$DefaultReaders'):
                 r.removefromreadergroup(newgroup)
             self.assertEquals([], PCSCReader.readers(newgroup))
