@@ -6,7 +6,7 @@ thru testsuite_scard.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -37,7 +37,8 @@ import sys
 sys.path += ['..']
 
 try:
-    from local_config import expectedATRs, expectedReaders, expectedReaderGroups, expectedATRinReader
+    from local_config import expectedATRs, expectedReaders
+    from local_config import expectedReaderGroups, expectedATRinReader
 except:
     print 'execute test suite first to generate the local_config.py file'
     sys.exit()
@@ -59,7 +60,10 @@ class testcase_getATR(unittest.TestCase):
     def _getATR(self, r):
         if r < len(expectedATRs) and [] != expectedATRs[r]:
             hresult, hcard, dwActiveProtocol = SCardConnect(
-                self.hcontext, self.readers[r], SCARD_SHARE_SHARED, SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
+                self.hcontext,
+                self.readers[r],
+                SCARD_SHARE_SHARED,
+                SCARD_PROTOCOL_T0 | SCARD_PROTOCOL_T1)
             self.assertEquals(hresult, 0)
 
             try:
