@@ -6,7 +6,7 @@ thru testsuite_scard.py.
 
 __author__ = "http://www.gemalto.com"
 
-Copyright 2001-2010 gemalto
+Copyright 2001-2012 gemalto
 Author: Jean-Daniel Aussel, mailto:jean-daniel.aussel@gemalto.com
 
 This file is part of pyscard.
@@ -49,11 +49,18 @@ class testcase_geterrormessage(unittest.TestCase):
 
         hresult = SCardReleaseContext(123L)
         if 'win32' == sys.platform:
-            self.assertEquals((SCARD_E_INVALID_HANDLE == hresult or ERROR_INVALID_HANDLE == hresult), True)
+            self.assertEquals((
+                SCARD_E_INVALID_HANDLE == hresult or \
+                ERROR_INVALID_HANDLE == hresult),
+                True)
         else:
             self.assertEquals((SCARD_E_INVALID_HANDLE == hresult), True)
-        self.assertEquals((SCardGetErrorMessage(hresult).rstrip() == 'Invalid handle.'.rstrip() or
-             SCardGetErrorMessage(hresult).rstrip() == 'The handle is invalid.'.rstrip()), True)
+        self.assertEquals((
+            SCardGetErrorMessage(hresult).rstrip() == \
+                'Invalid handle.'.rstrip() or \
+            SCardGetErrorMessage(hresult).rstrip() == \
+                'The handle is invalid.'.rstrip()),
+            True)
 
 
 def suite():
